/**
 * @author Bill Bejeck 6/30/2008
 *
 * Used to generate required Flex artifacts for deployment
 * Usage:
 *       $ grails flex-tasks wrapper - will generate a gsp wrapper file to load the flash player, by default file named index.gsp and placed in web-apps
 *       $ grails flex-tasks compile - will compile flex code into a swf file for deployment, by default swf file is placed in web-apps
 *       $ grails flex-tasks - will run all of the above tasks
 */

Ant.property(environment:"env")   
grailsHome = Ant.project.properties."env.GRAILS_HOME"
basedir = Ant.project.properties.basedir

Ant.property(file:"${basedir}/flex.properties")
def antProp = Ant.project.properties

def mxmlFile = antProp.'mxml.file'
def outputFile = antProp.'output.file'
def flexHome = antProp.'FLEX_HOME'

Ant.taskdef (name:'mxmlc', classname:'flex.ant.MxmlcTask', classpath:"${grailsHome}/ant/lib/flexTasks.jar")
Ant.taskdef (name:'gspWrapper', classname:'flex.ant.HtmlWrapperTask', classpath:"${grailsHome}/ant/lib/flexTasks.jar")

args = System.getProperty("grails.cli.args")


target('default':'Can choose to create gsp wrapper file or compile flex to swf or run both'){
if(args){
	if(args.equals('wrapper')){
		wrap()
    }else if(args.equals('compile')){
	    compile()
    }else{
         println("'"+args+"'  not a valid option")	 
    }
 }else{
        runAll()
 }
}

target(runAll:"Runs all Flex tasks"){
	depends(compile,wrap)
}

target(clean:"Deletes the previous SWF file"){
		Ant.delete(file:outputFile)
}

target(compile:'Compile Flex project into SWF file'){	
	depends(clean)
	Ant.mxmlc( file:mxmlFile,
	           output:outputFile,
	           incremental:antProp.incremental,
	           'actionscript-file-encoding':antProp.encoding,
			   'keep-generated-actionscript':antProp.generated) {
				
			     'load-config'(filename:"${flexHome}/frameworks/flex-config.xml")
			     'compiler.library-path'(dir:"${flexHome}/frameworks", append:"true"){
				                include(name:"libs")
				                include(name:"../bundles/{locale}")
				  }
				
		          'source-path'('path-element':"${flexHome}/frameworks")
		          'default-size'(width:antProp.'flex.width',height:antProp.'flex.height')
	           }
}

target(cleanWrap:"Clean up wrapper, wrapper related files"){
	Ant.delete(file:'web-app/AC_OETags.js')
	Ant.delete(file:antProp.output+'/'+antProp.file)
	Ant.delete(file:'web-app/playerProductInstall.swf')
	Ant.delete(dir:'web-app/history')
}

target(wrap:"Creates a gsp wrapper to load the flash player"){
    depends(cleanWrap)
	Ant.gspWrapper(title:antProp.title,
	               file:antProp.file, 
	               height:antProp.height,
	               width:antProp.width,
	               bgcolor:antProp.bgcolor,
	               application:antProp.application,
	               swf:antProp.swf,
	               'version-major':antProp.'version-major',
	               'version-minor':antProp.'version-minor',
	               'version-revision':antProp.'version-revision',
	               history:antProp.history,
	               template:antProp.template,
	               output:antProp.output)
}
